Package 'shinyresults'

Title: A collection of shiny apps and modules to visualize/handle model results
Description: A collection of shiny apps and modules to explore and visualize time series of modelling results.
Authors: Jan Philipp Dietrich [aut, cre] (affiliation: Potsdam Institute for Climate Impact Research, ORCID: <https://orcid.org/0000-0002-4309-6431>), Florian Humpenoeder [aut] (affiliation: Potsdam Institute for Climate Impact Research), Pascal Sauer [aut] (affiliation: Potsdam Institute for Climate Impact Research, ORCID: <https://orcid.org/0000-0002-6856-8239>), Patrick Rein [aut] (affiliation: Potsdam Institute for Climate Impact Research, ORCID: <https://orcid.org/0000-0001-9454-8381>)
Maintainer: Jan Philipp Dietrich <[email protected]>
License: BSD_2_clause + file LICENSE
Version: 0.37.2
Built: 2026-05-15 14:05:48 UTC
Source: https://github.com/pik-piam/shinyresults

Help Index


Analyze Model Statistics

Description

Shiny app to analyze statistics collected with runstatistics and merged with mergestatistics

Usage

appModelstats(
  files = c("https://www.pik-potsdam.de/rd3mod/magpie.rds",
    "https://www.pik-potsdam.de/rd3mod/remind.rds"),
  resultsfolder = NULL
)

Arguments

files

path to rds-files from which statistics should be read

resultsfolder

path to a folder containing model results of the corresponding runs

Author(s)

Jan Philipp Dietrich


appResults

Description

appResults allows to explore and visualize time series of modelling results.

Usage

appResults(
  cfg = getOption("appResults"),
  readFilePar = FALSE,
  variableConfig = NULL,
  port = 3838,
  ...
)

Arguments

cfg

config-file containing information about one or more models on the items listed below. Usually you provide these settings in your .Rprofile as a list constructed as follows (to explore REMIND results please replace all occurrences of magpie with remind): url <- https://rse.pik-potsdam.de/data/magpie/results/rev1 options(appResults = list(MAgPIE = list(file = paste0(url, "/reduced_overview.rds"), resultsfolder=url, valfile=paste0(url, "/validation.rds"), username="xxx", password="yyy")))

file - Overview file in rds format containing a list of all runs available. To get access to all available filters use overview.rds (takes 15s longer to load) instead of reduced_overview.rds. resultsfolder - folder in which model results are stored in rds format. valfile - validation data. Can be a CSV/MIF file or rds file with a quitte object (saved with saveRDS). NULL by default; in this case the user can upload files directly in the tool. Can also be a named character vector of multiple validation files. username - username to access "file" and "resultsfolder". password - password to access "file" and "resultsfolder". selectionSets - named list of selection sets per filter column. Each element is a named list mapping set labels to character vectors of values. Example: list(region = list("All EUR regions" = c("EUC", "EUS", "EUW", "DEU")))

readFilePar

read report data files in parallel (faster) (TRUE) or in sequence (FALSE)

variableConfig

Path to a YAML configuration file with variable presets, or NULL to use default config. The config defines presets for the Dashboard tab and quick-load options in plot tabs. See loadVariableConfig.

port

Port number for the Shiny app (default: 3838). Using a fixed port allows consistent URLs for bookmarking.

...

additional information to overwrite one of the settings from the cfg directly: file, resultsfolder, valfile, username, password, or selectionSets.

Author(s)

Florian Humpenoeder, Jan Philipp Dietrich, Lavinia Baumstark, Pascal Sauer


appResultsLocal

Description

version of appResults which is optimized to run on a local model folder. In contrast to appResults, appResultsLocal only requires the path to an output folder (with subfolders for each run).

Usage

appResultsLocal(folder = "output/", valfile = NULL)

Arguments

folder

output folder containing the runs to be analyzed as subfolders (e.g. folder "output" in a MAgPIE model folder)

valfile

Path to a validation file, preferably in rds format, but can also be provided as mif (in the latter case it will be converted to rds first). If not path is given the function will look automatically for an validation file in the output folder

Author(s)

Jan Philipp Dietrich, Lavinia Baumstark

See Also

appResults